@@ -27,6 +27,8 @@ try:
 except:
     ISQUATERNION = False
 
+from numtools.vgextended import matrix_transform
+
 # ============================================================================
 # ⚠ NOTE ⚠
 # ----------------------------------------------------------------------------
@@ -483,7 +485,7 @@ class RCSys(object):
         if rot_only:
             # apply only rotational transformation
             matrix = convert_33_to_44(matrix[:3, :3])
-        grounded = vg.matrix.transform(np.array(vertices), matrix)
+        grounded = matrix_transform(np.array(vertices), matrix)
         if not to_csys:
             return grounded
         if isinstance(to_csys, int):
@@ -529,11 +531,11 @@ class RCSys(object):
             matrix = convert_33_to_44(matrix[:3, :3])
         if not from_csys:
             # import vertices from ground
-            return vg.matrix.transform(np.array(vertices), matrix)
+            return matrix_transform(np.array(vertices), matrix)
         if isinstance(from_csys, int):
             from_csys = self.reg[from_csys]
         grounded = from_csys.export_vertices(vertices)
-        return vg.matrix.transform(np.array(grounded), self._MI)
+        return matrix_transform(np.array(grounded), self._MI)
 
     def quaternion(self):
         if not ISQUATERNION:
